@@ -481,7 +481,7 @@ main(int argc, char **argv)
 		break;
 	case SHOWINDVFILES:
 		if (filelist == NULL) {
-			(void) fprintf(stderr, "%s: must specify file list with -fi.\n", pname);
+			(void) fprintf(stderr, "%s: must specify file list with -f.\n", pname);
 			finish(-1);
 		}
 
