@@ -52,6 +52,7 @@
 #include <errno.h>
 #include <stdio.h>
 #include <string.h>
+#include <strings.h>
 #include <signal.h>
 #include <math.h>
 #include <pwd.h>
@@ -627,7 +628,6 @@ do_nfs_count(my_fsid fsid, ino_t ino, char *osname, char *sfsname,
 					   AF_INET);
 
 			if (hp) {
-				char *index();
 				char *dotp;
 
 				sprintf(prefix, "%s", hp->h_name);
@@ -866,7 +866,6 @@ CountSrc(ipaddrt src)
 	    hp = gethostbyaddr((char *) &ccp->cl_ipaddr,
 			       sizeof(ccp->cl_ipaddr), AF_INET);
 	    if (hp) {
-		char *index();
 		char *dotp;
 
 		sprintf(clnt_name, "%s", hp->h_name);
