@@ -25,6 +25,7 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
+#include <time.h>
 
 #include "nfswatch.h"
 #include "externs.h"
@@ -164,7 +165,6 @@ setup_screen(char *device)
 {
 	int len;
 	char *tstr;
-	char *ctime();
 	char buf[BUFSIZ];
 	struct timeval tv;
 	register struct scrtxt *st;
@@ -359,7 +359,6 @@ void
 update_screen(void)
 {
 	char *tstr;
-	char *ctime();
 	float percent;
 	struct timeval tv;
 	register int i, nfstotal;
